PEL: Only hexdump the UserData data, not header

In the case where this is no built in or user defined parser for a
UserData PEL section, peltool will hexdump it.

Instead of hexdumping the whole section, which includes the header,
print the  component ID, subtype, and version fields from the section
header separately, and only hexdump the data:

"User Data 5": {
    "Section Version":          "3",
    "Sub-section type":         "2",
    "Created by":               "0x1000",
    "Data": [
        "01 02 03 04 05 06 07 08  09 0A 0B 0C 0D 22 5C 41  |  .............\"\\A",
    ]
}

Signed-off-by: Matt Spinler <spinler@us.ibm.com>
Change-Id: Ie6c791fcc5c23565ca55d0bbf8d0cbb643234f66
diff --git a/extensions/openpower-pels/json_utils.hpp b/extensions/openpower-pels/json_utils.hpp
index e122f47..71a85e3 100644
--- a/extensions/openpower-pels/json_utils.hpp
+++ b/extensions/openpower-pels/json_utils.hpp
@@ -24,11 +24,12 @@
 
 /**
  * @brief get hex dump for PEL section in json format.
  * @param[in] const void* - Raw PEL data
  * @param[i] size_t - size of Raw PEL
  * @return char * - the Hex dump
  */
-char* dumpHex(const void* data, size_t size);
+char* dumpHex(const void* data, size_t size, size_t indentCount);
 
 /**
  * @brief Inserts key-value into a JSON string
@@ -24,11 +24,12 @@
 /**
  * @brief get hex dump for PEL section in json format.
- * @param[in] const void* - Raw PEL data
- * @param[i] size_t - size of Raw PEL
+ * @param[in] const void* data - Raw PEL data
+ * @param[i] size_t size - size of Raw PEL
+ * @param[in] size_t indentCount - The number of indent levels to indent
  * @return char * - the Hex dump
  */